# Draggable [![Build Status](https://travis-ci.org/chrisborrowdale/draggable.png)](https://travis-ci.org/chrisborrowdale/draggable)

A lightweight dragging plugin for jQuery

## Getting Started

Download the [production version][min] or the [development version][max].

[min]: https://github.com/chrisborrowdale/draggable/blob/master/dist/jquery.draggable.min.js
[max]: https://github.com/chrisborrowdale/draggable/blob/master/dist/jquery.draggable.js

In your web page:

```html
<script src="jquery.js"></script>
<script src="dist/draggable.min.js"></script>
<script>
jQuery(function($) {
    $('#js-element').draggable();
});
</script>
```

## Documentation

Draggable is a minimal and lightweight jQuery plugin for simply dragging an element from one position to another, it's only 2kb when minified, and working on Chrome, Firefox, Safari, IE8 and greater as well as mobile devices.

It's super customisable, with three callbacks for when you start dragging, while you're dragging and when you finish dragging.  Draggable focusses solely on the dragging.

### Usage

Simply call the plugin on your element like so:

```js
$('.drag-element').draggable();
```

Don't forget to add absolute positioning to your element you want to drag and some z-index just to be safe, for example:

```css
.drag-element {
    position: absolute;
    z-index: 99999;
}
```

If you want to customise it further such as using the callbacks or changing the dragging class which is applied when the element is dragging (default is js-dragging), you can:

```js
$('.drag-element').draggable({

    draggingClass: 'my-new-dragging-class',

    startDragging: function() {
        // When I start dragging run this code...
    },

    dragging: function() {
        // While I am dragging run this code...
    },

    endDragging: function() {
        // When I finish dragging run this code...
    }

});
```

## Release History
0.1.0 - Initial Release
