/*
 * Draggable
 * 
 *
 * Copyright (c) 2013 Chris Borrowdale
 * Licensed under the MIT license.
 */

(function($) {

  $.fn.draggable = function(options) {

    /*
      Plugin Options, element is the element we want to drag, start callback is when we
      start dragging, dragging is obviously when we're dragging and end dragging is
      called when the user mouses up and, ends dragging.
    */
    var $element;

    options = $.extend({
      element: "",
      startDragging: function() {},
      dragging: function() {},
      endDragging: function() {},
      docReady: function() {},
      draggingClass: 'js-dragging'
    }, options);

    if (options.element === '') {
      $element = this;
    } else {
      $element = options.element;
    }

    var mobileThis = this;
    options.docReady();

    $element.on("mousedown", function(event) {
      event.originalEvent.preventDefault();

      // Start dragging callback
      options.startDragging();

      /*
        If the options.element is null then get the element used when instantiating
        the plugin and add a class of js-dragging but also assign this to a $this
        variable which we'll use later on.
      */
      if (options.element === '') {
        $this = $(this).addClass(options.draggingClass);
      }

      /*
        Get the height, width and assign to vars, then calculate the positionX and Y
        by taking the offset left/top and adding the width/height minus the position
        the element is on the screen.
      */

      var el = {};
      el.height = $this.outerHeight();
      el.width = $this.outerHeight();
      el.posX = $this.offset().left + el.width - event.pageX;
      el.posY = $this.offset().top + el.height - event.pageY;

      $this.on("mousemove", function(event) {

        var coordinates = {
          x: event.pageX + (el.posX - el.width),
          y: event.pageY + (el.posY - el.height)
        };

        options.dragging(coordinates);

        $('.' + options.draggingClass).css({
          'top': (event.pageY + el.posY - el.height) - $('body').offset().top,
          'left': event.pageX + el.posX - el.width
        });

        event.preventDefault();

      });

      /*
        When we mouseup we're done dragging! Remove the dragging class but before that run
        the endDragging callback.
      */
      $this.on("mouseup", function(event) {
        var coordinates = {
          x: event.pageX + (el.posX - el.width),
          y: event.pageY + (el.posY - el.height)
        };
        options.endDragging(coordinates);

        if (options.element === '') {
          $(this).removeClass(options.draggingClass);
        }
      });
    });


    /* Touch Support: Touch support for iOS devices untested on anything else */

    /*
      Touch Start event, when the user first taps the screen to begin dragging, get the
      element if it has been set if not then get the 'mobileThis' for some reason it was
      flagging up problems just trying to access this.  Then $this to the element and add
      the dragging class.
    */
    var $this, touchEl, touch;

    document.addEventListener('touchstart', function(event) {
      options.startDragging();
      event.preventDefault();
      touch = event.touches[0];


      if (options.element === '') {
        $element = mobileThis;
        $this = $element.addClass(options.draggingClass);
      } else {
        $element = options.element;
      }



      touchEl = {};
      touchEl.height = $this.outerHeight();
      touchEl.width = $this.outerWidth();
      touchEl.posX = $this.offset().left + touchEl.width - event.pageX;
      touchEl.posY = $this.offset().top + touchEl.height - event.pageY;
    });

    document.addEventListener('touchmove', function() {

      $('.' + options.draggingClass).css({
        'top': (touch.pageY + touchEl.posY - touchEl.height) - $('.drag-wrapper').offset().top,
        'left': touch.pageX + touchEl.posX - touchEl.width
      });

      var coordinates = {
        x: touch.pageX + (touchEl.posX - touchEl.width),
        y: touch.pageY + (touchEl.posY - touchEl.height)
      };

      options.dragging(coordinates);
    }, false);

    document.addEventListener('touchend', function(event) {
      options.endDragging();
      event.preventDefault();
      touch = event.touches[0];
      $this.removeClass(options.draggingClass);
    }, false);
  };
})(jQuery);
